@@ -5,7 +5,7 @@
 # BSD license - see COPYING for details
 
 """Servers for the KAT device control language.
-   """
+"""
 
 import socket
 import errno
@@ -16,7 +16,7 @@ import logging
 import sys
 import re
 import time
-from .katcp import DeviceMetaclass, ExcepthookThread, Message, MessageParser, \
+from .core import DeviceMetaclass, ExcepthookThread, Message, MessageParser, \
                    FailReply, AsyncReply
 from .sampling import SampleReactor, SampleStrategy, SampleNone
 
@@ -996,7 +996,7 @@ class DeviceServer(DeviceServerBase):
         for client in clients:
             try:
                 addr = ":".join(str(part) for part in client.getpeername())
-            except socket.error, e:
+            except socket.error:
                 # client may be gone, in which case just send a description
                 addr = repr(client)
             self.reply_inform(sock, Message.inform("client-list", addr), msg)
