@@ -198,10 +198,10 @@ class TestDeviceServer(unittest.TestCase, TestUtilMixin):
         self.client.request(katcp.Message.request("sensor-value", mid=mid()))
         self.client.request(katcp.Message.request("sensor-value", "an.int", mid=mid()))
         self.client.request(katcp.Message.request("sensor-value", "an.unknown", mid=mid()))
-        self.client.request(katcp.Message.request("sensor-sampling", "an.int", mid=mid()))
-        self.client.request(katcp.Message.request("sensor-sampling", "an.int", "differential", "2", mid=mid()))
-        self.client.request(katcp.Message.request("sensor-sampling", mid=mid()))
-        self.client.request(katcp.Message.request("sensor-sampling", "an.unknown", "auto", mid=mid()))
+        self.client.blocking_request(katcp.Message.request("sensor-sampling", "an.int", mid=mid()))
+        self.client.blocking_request(katcp.Message.request("sensor-sampling", "an.int", "differential", "2", mid=mid()))
+        self.client.blocking_request(katcp.Message.request("sensor-sampling", mid=mid()))
+        self.client.blocking_request(katcp.Message.request("sensor-sampling", "an.unknown", "auto", mid=mid()))
         self.client.blocking_request(katcp.Message.request("sensor-sampling", "an.int", "unknown", mid=mid()))
 
         self.server.log.trace("trace-msg")
@@ -456,10 +456,8 @@ class TestDeviceServer(unittest.TestCase, TestUtilMixin):
     def test_sampling(self):
         """Test sensor sampling."""
         self.client.request(katcp.Message.request("sensor-sampling", "an.int", "period", 100))
-        start = time.time()
         time.sleep(1.0)
         self.client.request(katcp.Message.request("sensor-sampling", "an.int", "none"))
-        end = time.time()
         time.sleep(0.5)
 
         msgs = self.client.messages()
